.. _privacy_policy:

Privacy Policy
==============

Effective Date: Aug 26th, 2022

Welcome
-------

Tumult Labs provides Differential Privacy software and services to companies, 
agencies and institutions. We only use your personal information for the purpose 
of managing our business and our relationship with you. This Privacy Notice 
describes the ways that Tumult Labs protects the privacy of visitors to our website 
and users of our hosted demonstration environment. We protect the personal 
information of our customers, partners and employees in accordance with our 
agreements and applicable law.

Privacy and transparency are core to who we are as a company, and we have done 
our best to make our Privacy Notice easy to read and to allow you to find what 
you are looking for. If you would like any more information, just reach out to us 
at `info@tmlt.io <mailto:info@tmlt.io>`_. 


How does Tumult Labs use my personal information?
-------------------------------------------------

To respond to your requests, questions and feedback
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
If you contact us with questions or feedback, we will use your business contact 
information to respond to you.

To keep you updated (with your consent)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
We keep our network up to date on platform updates via e-mail. If you wish to be 
added to our mailing list, we ask that you provide your business contact 
information (including your name, company info, and business e-mail address) 
either through our website, contact one of our team members or send us an e-mail.

We respect your wishes when it comes to communication. If you wish to unsubscribe, 
just click the unsubscribe link at the bottom of every email or send us an email at 
`info@tmlt.io <mailto:info@tmlt.io>`_ and we will stop sending you marketing and promotional emails within 10 days.

A note about tracking and analytics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Unlike most companies, Tumult Labs does not collect any personal information about 
you for the purpose of tracking and analytics. Our website utilizes `Plausible.io <https://plausible.io/>`_, 
a privacy friendly and open source alternative that does not use cookies or other 
tracking technology.

Does Tumult Labs sell or share my personal information?
-------------------------------------------------------
No. We do not sell your personal information, and we do not share it with third parties.

Tumult Labs uses some tools, apps and services to communicate with users. If these tools 
are provided by third parties, we make sure the third parties are not allowed to access 
your personal information, copy it, or use it for any purpose other than to deliver the 
service to us.  A list of third-party service providers is available upon request.

How do I get in touch?
----------------------
If you have questions or comments about this privacy notice or our privacy practices, 
please contact us.

The best way to reach us is via email at `info@tmlt.io <mailto:info@tmlt.io>`_.

You can also send us a letter: Tumult Labs Inc, 201 W Main Street, Suite B26, Durham, NC 
27701 USA.

